==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/mixin/block/BedBlockMixin.java <==
package cc.thonly.reverie_dreams.mixin.block;

import cc.thonly.reverie_dreams.entity.npc.NPCEntityImpl;
import cc.thonly.reverie_dreams.interfaces.IDreamPillowManager;
import cc.thonly.reverie_dreams.item.prop.DreamPillowItem;
import cc.thonly.reverie_dreams.server.DreamPillowManager;
import net.minecraft.class_1269;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2244;
import net.minecraft.class_2338;
import net.minecraft.class_2343;
import net.minecraft.class_238;
import net.minecraft.class_2383;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_3545;
import net.minecraft.class_3965;
import net.minecraft.server.MinecraftServer;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import java.util.List;

@Mixin(class_2244.class)
public abstract class BedBlockMixin extends class_2383 implements class_2343 {
    protected BedBlockMixin(class_2251 settings) {
        super(settings);
    }

    @Inject(method = "onUse", at = @At("HEAD"))
    public void onUse(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_3965 hit, CallbackInfoReturnable<class_1269> cir) {
        if (state.method_11654(class_2244.field_9968)) {
            this.wakeNpc(world, pos);
        }
    }

    @Unique
    public boolean wakeNpc(class_1937 world, class_2338 pos) {
        List<NPCEntityImpl> list = world.method_8390(NPCEntityImpl.class, new class_238(pos), class_1309::method_6113);
        if (list.isEmpty()) {
            return false;
        }
        list.getFirst().method_18400();
        return true;
    }

    @Inject(method = "onBreak", at = @At("HEAD"))
    public void onBreak(class_1937 world, class_2338 pos, class_2680 state, class_1657 player, CallbackInfoReturnable<class_2680> cir) {
        if (!world.field_9236 && world instanceof class_3218 serverWorld) {
            MinecraftServer server = serverWorld.method_8503();
            IDreamPillowManager iDreamPillowManager = (IDreamPillowManager) server;
            DreamPillowManager dreamPillowManager = iDreamPillowManager.getDreamPillowManager();
            DreamPillowManager.WorldEntry worldEntry = dreamPillowManager.get(serverWorld);
            class_3545<Boolean, class_2338> bedHead = DreamPillowItem.getBedHead(serverWorld, pos);
            if (bedHead.method_15442()) {
                worldEntry.remove(bedHead.method_15441());
            }
        }
    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/mixin/block/BedBlockMixin.java <==
package cc.thonly.reverie_dreams.mixin.block;

import cc.thonly.reverie_dreams.entity.npc.BaseNPCLikeEntity;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import java.util.List;
import net.minecraft.class_1269;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2244;
import net.minecraft.class_2338;
import net.minecraft.class_2343;
import net.minecraft.class_238;
import net.minecraft.class_2383;
import net.minecraft.class_2680;
import net.minecraft.class_3965;

@Mixin(class_2244.class)
public abstract class BedBlockMixin extends class_2383 implements class_2343 {
    protected BedBlockMixin(class_2251 settings) {
        super(settings);
    }

    @Inject(method = "useWithoutItem", at = @At("HEAD"))
    public void onUse(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_3965 hit, CallbackInfoReturnable<class_1269> cir) {
        if (state.method_11654(class_2244.field_9968)) {
            this.wakeNpc(world, pos);
        }
    }

    @Unique
    public boolean wakeNpc(class_1937 world, class_2338 pos) {
        List<BaseNPCLikeEntity> list = world.method_8390(BaseNPCLikeEntity.class, new class_238(pos), class_1309::method_6113);
        if (list.isEmpty()) {
            return false;
        }
        list.getFirst().method_18400();
        return true;
    }

}
